@@ -1,3 +1,4 @@
+# type: ignore
 from typing import List, Type
 
 import arrow
@@ -11,10 +12,18 @@ from canvas_workflow_kit.protocol import (
     ExternallyAwareClinicalQualityMeasure,
     ProtocolResult
 )
-from canvas_workflow_kit.recommendation import PerformRecommendation, ReferRecommendation, TaskRecommendation
+from canvas_workflow_kit.recommendation import (
+    PerformRecommendation,
+    ReferRecommendation,
+    TaskRecommendation
+)
 from canvas_workflow_kit.timeframe import Timeframe
 # flake8: noqa
-from canvas_workflow_kit.value_set.v2018 import Diabetes, OphthalmologicalServices, RetinalOrDilatedEyeExam
+from canvas_workflow_kit.value_set.v2018 import (
+    Diabetes,
+    OphthalmologicalServices,
+    RetinalOrDilatedEyeExam
+)
 from canvas_workflow_kit.value_set.value_set import ValueSet
 
 
@@ -56,32 +65,29 @@ class ClinicalQualityMeasure131v6(ExternallyAwareClinicalQualityMeasure, Diabete
 
     More information: https://ecqi.healthit.gov/ecqm/measures/cms131v6
     """
+    class Meta:
 
-    title = 'Diabetes: Eye Exam'
+        title = 'Diabetes: Eye Exam'
 
-    description = ('Patients 18-75 years of age with diabetes who have not had a retinal or '
-                   'dilated eye exam by an eye care professional.')
-    information = 'https://ecqi.healthit.gov/ecqm/measures/cms131v6'
+        version = '2019-08-02v1'
 
-    identifiers = ['CMS131v6']
+        description = ('Patients 18-75 years of age with diabetes who have not had a retinal or '
+                       'dilated eye exam by an eye care professional.')
+        information = 'https://ecqi.healthit.gov/ecqm/measures/cms131v6'
 
-    types = ['CQM']
+        identifiers = ['CMS131v6']
 
-    responds_to_event_types = [
-        events.HEALTH_MAINTENANCE,
-    ]
+        types = ['CQM']
 
-    authors = [
-        'National Committee for Quality Assurance',
-    ]
+        responds_to_event_types = [
+            events.HEALTH_MAINTENANCE,
+        ]
 
-    @classmethod
-    def enabled(cls) -> bool:
-        return True
+        authors = [
+            'National Committee for Quality Assurance',
+        ]
 
-    @property
-    def references(self) -> List[str]:
-        return [
+        references = [
             'American Diabetes Association. Microvascular complications and foot care. Sec. 10. In Standards of Medical Care in Diabetes 2017. Diabetes Care 2017;40(Suppl. 1):S88-S98',
             'American Diabetes Association. 2009. "Standards of Medical Care in Diabetes-2009." Diabetes Care 2009 32 (Suppl 1):S6-S12. doi:10.2337/dc09-S006.',
             'American Diabetes Association. 2013. Diabetes Basics. www.diabetes.org/diabetes-basics/?loc=GlobalNavDB',
@@ -91,14 +97,17 @@ class ClinicalQualityMeasure131v6(ExternallyAwareClinicalQualityMeasure, Diabete
             'Centers for Disease Control and Prevention. 2014. CDC Features. Diabetes Latest. www.cdc.gov/features/diabetesfactsheet/.',
         ]
 
-    compute_on_change_types = [
-        ClinicalQualityMeasure.CHANGE_PROTOCOL_OVERRIDE,
-        ClinicalQualityMeasure.CHANGE_CONDITION,
-        ClinicalQualityMeasure.CHANGE_PATIENT,
-        ClinicalQualityMeasure.CHANGE_REFERRAL_REPORT,
-    ]
+        compute_on_change_types = [
+            ClinicalQualityMeasure.CHANGE_PROTOCOL_OVERRIDE,
+            ClinicalQualityMeasure.CHANGE_CONDITION,
+            ClinicalQualityMeasure.CHANGE_PATIENT,
+            ClinicalQualityMeasure.CHANGE_REFERRAL_REPORT,
+        ]
+
+    @classmethod
+    def enabled(cls) -> bool:
+        return True
 
-    funding_source = ''
     _on_date = None
     _in_period = None
     _finding = None
@@ -107,10 +116,6 @@ class ClinicalQualityMeasure131v6(ExternallyAwareClinicalQualityMeasure, Diabete
     def specific_visits(self) -> Type[ValueSet]:
         return super().specific_visits | OphthalmologicalServices
 
-    @classmethod
-    def revision(cls) -> str:
-        return '2019-08-02v1'
-
     def in_denominator(self) -> bool:
         """
         Denominator: Equals Initial Population
